
### The "rethinking" package here is loaded just to extract the data on GDP and Ruggedness
### ggplot2 is necessary for  graphs
library(rethinking)
library(ggplot2)


#### Ruggedness dataset from Rethinking ####
data("rugged")
d<-rugged

# calculate log of outcome GDP
d$logGDP<-log(d$rgdppc_2000)

#extract countries with GDP data, i.e. cases without missing data
dd<-d[complete.cases(d$rgdppc_2000),]

# rescale variables
dd$logGDPstd<-dd$logGDP/mean(dd$logGDP)
dd$ruggedstd<-dd$rugged/max(dd$rugged)

#### Dichotomous variable for African Countries
dd$afr<- ifelse(dd$cont_africa==1, 1, 0)
#### Create term for interaction
dd$int<-dd$afr*dd$ruggedstd

###Estimate the regressions, first without, then with the interaction
summary(lm(logGDPstd~ruggedstd+afr, data=dd))
summary(lm(logGDPstd~ruggedstd+afr+int, data=dd))

### The following creates a text variable that will be used in the plot
dd$Africa[dd$afr==1]<-"Africa"
dd$Africa[dd$afr==0]<-"Not Africa"

### The following creates the plot and changes its appearance
p<-ggplot(data = dd, mapping = aes(x = ruggedstd, y = logGDPstd,   color = Africa, fill=Africa)) +
  geom_jitter() + # Use geom_jitter instead of geom_point, otherwise the points are drawn over each other
  geom_smooth(method='lm',  se=TRUE,  ) # Draw a linear regression line through the points.
p<-p+theme(text=element_text(size=20))
p+geom_point(size=1.5)
p<-p+labs(title = "GDP by Ruggedness", x= "Ruggedness (Std)", y="Log GDP (Std)")
p

### Run a Likelihood ratio test
m1<-lm(logGDPstd~ruggedstd+afr, data=dd)
m2<-lm(logGDPstd~ruggedstd+afr+int, data=dd)
library(lmtest)
lrtest(m1, m2)

#### Simmetry of interactions ####
library(foreign)
d<-read.dta("https://stats.idre.ucla.edu/stat/stata/examples/methods_matter/chapter12/catholic.dta")
head(d)
d$stdmath8<-((d$math8-mean(d$math8))/sd(d$math8))
d$stdread8<-((d$read8-mean(d$read8))/sd(d$read8))
d$stdmath12<-((d$math12-mean(d$math12))/sd(d$math12))
d$int<-d$stdread8*d$stdmath8
precis(d)
set.seed(546)
d2<-d[sample(1:nrow(d), 400), ]
head(d2)
summary(d2)
summary(lm(stdmath12~stdread8+stdmath8+int, data=d2))

#https://cran.r-project.org/web/packages/interactions/vignettes/interactions.html
library(jtools)
library(interactions)
library(sandwich)


m2<-(lm(stdmath12~stdread8*stdmath8, data=d2))
summ(m2)

m2<-(lm(stdmath12~stdread8*stdmath8, data=d2))

### Plot from "Interactions"
interact_plot(m2, pred=stdmath8, modx=stdread8, interval=TRUE, int.width=0.89, plot.points=TRUE, line.thickness = 3,
              x.label = "Std Grade 8 Math Scores", y.label = "Std Grade 12 Math Scores",
              int.type = c("confidence"),   legend.main = "Std Grade 8 Reading Scores",
              )


interact_plot(m2, pred=stdread8, modx=stdmath8,  plot.points=TRUE, line.thickness = 3,
              x.label = "Std Grade 8 Reading Scores", y.label = "Std Grade 12 Math Scores",
                 legend.main = "Std Grade 8 Math Scores",
)

#### Slopes analysis
sim_slopes(m2, pred=stdmath8, modx=stdread8, johnson_neyman = FALSE)
sim_slopes(m2, pred=stdmath8, modx=stdread8, modx.values=c(-5,0,+5), johnson_neyman = FALSE)
ss<-sim_slopes(m2, pred=stdmath8, modx=stdread8, modx.values=c(-.5,0,+.5))
plot(ss)
sim_slopes(m2, pred=stdmath8, modx=stdread8, johnson_neyman = TRUE)
johnson_neyman(m2, pred = stdmath8, modx = stdread8, alpha = .05)


#### Example 1977 USA
states <- as.data.frame(state.x77)
fiti <- lm(Income ~ Illiteracy * Murder + `HS Grad`, data = states)
summ(fiti)


interact_plot(fiti, pred=Illiteracy, modx=Murder, interval=TRUE, int.width=0.95, plot.points=TRUE,
              line.thickness = 3,
              int.type = c("confidence"),   ) 

sim_slopes(fiti, pred = Illiteracy, modx = Murder,  johnson_neyman = FALSE)

johnson_neyman(fiti, pred = Illiteracy, modx = Murder, alpha = .05)


sim_slopes(fiti, pred = Illiteracy, modx = Murder,  modx.values=c(0, 8, 15))
